@@ -9,11 +9,12 @@ import shlex
 from typing import Iterable, Dict, List, Optional, Union
 
 import configobj
-import validate
+import configobj.validate as validate
 
 from .actions import Actions
 from .address_book import AddressBookCollection, AddressBookNameError, \
     VdirAddressBook
+from .query import Query
 
 
 logger = logging.getLogger(__name__)
@@ -175,12 +176,12 @@ class Config:
         except IOError as err:
             raise ConfigError(str(err))
 
-    def get_address_books(self, names: Iterable[str], queries: Dict
+    def get_address_books(self, names: Iterable[str], queries: Dict[str, Query]
                           ) -> AddressBookCollection:
         """Load all address books with the given names.
 
         :param names: the address books to load
-        :param dict queries: a mapping of address book names to search queries
+        :param queries: a mapping of address book names to search queries
         :returns: the loaded address books
         """
         all_names = {str(book) for book in self.abooks}
@@ -196,7 +197,7 @@ class Config:
         # We can not use AddressBookCollection.load here because we want to
         # select the collection based on the address book.
         for abook in collection:
-            abook.load(queries[abook.name], self.search_in_source_files) # type: ignore
+            abook.load(queries[abook.name], self.search_in_source_files)
         return collection
 
     def merge(self, other: Union[configobj.ConfigObj, Dict]) -> None:
